==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/NamespaceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NamespaceBuilder extends io.fabric8.kubernetes.api.model.NamespaceFluentImpl<io.fabric8.kubernetes.api.model.NamespaceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.Namespace,io.fabric8.kubernetes.api.model.NamespaceBuilder>{
  public NamespaceBuilder() {
    this(false);
  }
  public NamespaceBuilder(java.lang.Boolean validationEnabled) {
    this(new Namespace(), validationEnabled);
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.NamespaceFluent<?> fluent) {
    this(fluent, false);
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.NamespaceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Namespace(), validationEnabled);
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.NamespaceFluent<?> fluent,io.fabric8.kubernetes.api.model.Namespace instance) {
    this(fluent, instance, false);
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.NamespaceFluent<?> fluent,io.fabric8.kubernetes.api.model.Namespace instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.Namespace instance) {
    this(instance,false);
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.Namespace instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.NamespaceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.Namespace build() {
    Namespace buildable = new Namespace(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamespaceBuilder that = (NamespaceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/NamespaceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NamespaceBuilder extends io.fabric8.kubernetes.api.model.NamespaceFluentImpl<io.fabric8.kubernetes.api.model.NamespaceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.Namespace,io.fabric8.kubernetes.api.model.NamespaceBuilder>{
  public NamespaceBuilder() {
    this(false);
  }
  public NamespaceBuilder(java.lang.Boolean validationEnabled) {
    this(new Namespace(), validationEnabled);
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.NamespaceFluent<?> fluent) {
    this(fluent, false);
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.NamespaceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Namespace(), validationEnabled);
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.NamespaceFluent<?> fluent,io.fabric8.kubernetes.api.model.Namespace instance) {
    this(fluent, instance, false);
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.NamespaceFluent<?> fluent,io.fabric8.kubernetes.api.model.Namespace instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.Namespace instance) {
    this(instance,false);
  }
  public NamespaceBuilder(io.fabric8.kubernetes.api.model.Namespace instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.NamespaceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.Namespace build() {
    Namespace buildable = new Namespace(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamespaceBuilder that = (NamespaceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
